@@ -1363,8 +1363,23 @@ static int ryylex(YYSTYPE* lvalp, void* s) {
     if (queryPtr == queryEnd) {
         return EOF;
     }
-    if (*queryPtr == '-'  ||  *queryPtr == '.'  ||
 
+    if (FEATURE(misc, files_as_tables)  &&
+	(*queryPtr == '/'  ||
+	 (*queryPtr == '.'  &&
+	  ((queryPtr+1 < queryEnd  &&  queryPtr[1] == '/')  ||
+	   (queryPtr+2 < queryEnd  &&  queryPtr[1] == '.'  &&
+	    queryPtr[2] == '/'))))) {
+        while (queryPtr < queryEnd  &&  !isspace(*queryPtr)) {
+	    ++queryPtr;
+	}
+	lvalp->ident_val.ptr = stmt->queryPtr;
+	lvalp->ident_val.len = queryPtr - stmt->queryPtr;
+	stmt->queryPtr = queryPtr;
+	return IDENT;
+    }
+
+    if (*queryPtr == '-'  ||  *queryPtr == '.'  ||
 	(*queryPtr >= '0'  &&  *queryPtr <= '9')) {
 	/*
  	 *  Looks like a number
